"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const npmCheck = require("npm-check");
const core_1 = require("@checkup/core");
async function getDependencies(path) {
    let result;
    let packages;
    try {
        result = await npmCheck({ cwd: path });
    }
    catch (_a) {
        throw new Error('Could not check project dependencies');
    }
    packages = result.get('packages').map((pkg) => {
        return {
            packageName: pkg.moduleName,
            packageJsonVersion: pkg.packageJson,
            homepage: pkg.homepage,
            latest: pkg.latest,
            installed: pkg.installed,
            wanted: pkg.packageWanted,
            semverBump: pkg.bump === null ? 'current' : pkg.bump,
        };
    });
    return packages;
}
class OutdatedDependenciesTask extends core_1.BaseTask {
    constructor() {
        super(...arguments);
        this.taskName = 'outdated-dependencies';
        this.taskDisplayName = 'Outdated Dependencies';
        this.category = 'dependencies';
    }
    async run() {
        let outdatedDependencies = await getDependencies(this.context.cliFlags.cwd);
        let groupedDependencies = core_1.groupDataByField(outdatedDependencies, 'semverBump');
        return groupedDependencies.map((dependencyGroup) => this.toJson(core_1.buildResultFromProperties(dependencyGroup, dependencyGroup[0].semverBump)));
    }
}
exports.default = OutdatedDependenciesTask;
//# sourceMappingURL=outdated-dependencies-task.js.map